@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef PALAPELI_TRIGGERLISTVIEW_P_H
 #define PALAPELI_TRIGGERLISTVIEW_P_H
@@ -34,20 +22,20 @@ namespace Palapeli
 	class TriggerListProxyModel : public KCategorizedSortFilterProxyModel
 	{
 		public:
-			explicit TriggerListProxyModel(QObject* parent = 0)
+			explicit TriggerListProxyModel(QObject* parent = nullptr)
 				: KCategorizedSortFilterProxyModel(parent)
 			{
 				setCategorizedModel(true);
 				m_collator.setCaseSensitivity(Qt::CaseSensitive);
 			}
 		protected:
-			int compareCategories(const QModelIndex& left, const QModelIndex& right) const Q_DECL_OVERRIDE
+			int compareCategories(const QModelIndex& left, const QModelIndex& right) const override
 			{
 				const int categoryLeft = left.data(KCategorizedSortFilterProxyModel::CategorySortRole).value<int>();
 				const int categoryRight = right.data(KCategorizedSortFilterProxyModel::CategorySortRole).value<int>();
 				return categoryRight - categoryLeft;
 			}
-			bool subSortLessThan(const QModelIndex& left, const QModelIndex& right) const Q_DECL_OVERRIDE
+			bool subSortLessThan(const QModelIndex& left, const QModelIndex& right) const override
 			{
 				const QString textLeft = left.data(Qt::DisplayRole).toString();
 				const QString textRight = right.data(Qt::DisplayRole).toString();
@@ -61,7 +49,7 @@ namespace Palapeli
 	{
 		Q_OBJECT
 		public:
-			explicit TriggerListDelegateWidget(QWidget* parent = 0) : QWidget(parent)
+			explicit TriggerListDelegateWidget(QWidget* parent = nullptr) : QWidget(parent)
 			{
 				m_iconLabel = new QLabel(this);
 				m_nameLabel = new Palapeli::ElidingLabel(this);
@@ -107,33 +95,34 @@ namespace Palapeli
 	{
 		Q_OBJECT
 		public:
-			explicit TriggerListDelegate(QAbstractItemView* view, QObject* parent = 0) : KWidgetItemDelegate(view, parent)
+			explicit TriggerListDelegate(QAbstractItemView* view, QObject* parent = nullptr) : KWidgetItemDelegate(view, parent)
 			{
 				m_calculator = new Palapeli::TriggerListDelegateWidget(view);
 				m_calculator->setVisible(false);
 			}
-			void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const Q_DECL_OVERRIDE
+			void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const override
 			{
 				Q_UNUSED(index)
-				QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, 0);
+				QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, nullptr);
 			}
-			QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const Q_DECL_OVERRIDE
+			QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const override
 			{
 				updateItemWidgets(QList<QWidget*>() << m_calculator, option, index);
 				return m_calculator->minimumSizeHint();
 			}
 		protected:
-			QList<QWidget*> createItemWidgets(const QModelIndex &index) const Q_DECL_OVERRIDE
+			QList<QWidget*> createItemWidgets(const QModelIndex &index) const override
 			{
+				Q_UNUSED(index);
 				return QList<QWidget*>() << new Palapeli::TriggerListDelegateWidget(itemView());
 			}
-			void updateItemWidgets(QList<QWidget*> widgets, const QStyleOptionViewItem& option, const QPersistentModelIndex& index) const Q_DECL_OVERRIDE
+			void updateItemWidgets(QList<QWidget*> widgets, const QStyleOptionViewItem& option, const QPersistentModelIndex& index) const override
 			{
 				Palapeli::TriggerListDelegateWidget* widget = qobject_cast<Palapeli::TriggerListDelegateWidget*>(widgets[0]);
 				//adjust widget contents
 				widget->setIcon(index.data(Qt::DecorationRole).value<QIcon>());
 				widget->setText(index.data(Qt::DisplayRole).value<QString>());
-				disconnect(widget, 0, this, 0);
+				disconnect(widget, nullptr, this, nullptr);
 				widget->setTrigger(index.data(TriggerRole).value<Palapeli::Trigger>());
 				connect(widget, &TriggerListDelegateWidget::triggerChanged, this, &TriggerListDelegate::slotTriggerChanged);
 				//adjust widget geometry
@@ -151,7 +140,7 @@ namespace Palapeli
 				const QModelIndex index = focusedIndex();
 				QAbstractItemModel* model = const_cast<QAbstractItemModel*>(index.model());
 				model->setData(index, QVariant::fromValue(newTrigger), Palapeli::TriggerRole);
-				emit triggerChanged();
+				Q_EMIT triggerChanged();
 			}
 		private:
 			Palapeli::TriggerListDelegateWidget* m_calculator;
