@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "interactors.h"
 #include "piece.h"
@@ -40,12 +28,12 @@ Palapeli::MovePieceInteractor::MovePieceInteractor(QGraphicsView* view)
 static QGraphicsItem* findSelectableItemAt(const QPointF& scenePos, QGraphicsScene* scene)
 {
 	if (!scene)
-		return 0;
-	QList<QGraphicsItem*> itemsUnderMouse = scene->items(scenePos);
-	foreach (QGraphicsItem* itemUnderMouse, itemsUnderMouse)
+		return nullptr;
+	const QList<QGraphicsItem*> itemsUnderMouse = scene->items(scenePos);
+	for (QGraphicsItem* itemUnderMouse : itemsUnderMouse)
 		if (itemUnderMouse->flags() & QGraphicsItem::ItemIsSelectable)
 			return itemUnderMouse;
-	return 0;
+	return nullptr;
 }
 
 void Palapeli::MovePieceInteractor::determineSelectedItems(QGraphicsItem* clickedItem, Palapeli::Piece* clickedPiece)
@@ -55,7 +43,7 @@ void Palapeli::MovePieceInteractor::determineSelectedItems(QGraphicsItem* clicke
 	if (clickedItem->isSelected())
 	{
 		//clicked item is already selected -> include all selected items/pieces in this move
-		foreach (QGraphicsItem* selectedItem, selectedItems)
+		for (QGraphicsItem* selectedItem : selectedItems)
 		{
 			Palapeli::Piece* selectedPiece = Palapeli::Piece::fromSelectedItem(selectedItem);
 			if (selectedPiece)
@@ -66,7 +54,7 @@ void Palapeli::MovePieceInteractor::determineSelectedItems(QGraphicsItem* clicke
 	else
 	{
 		//clicked item is not selected -> deselect everything else and select only this item
-		foreach (QGraphicsItem* selectedItem, selectedItems)
+		for (QGraphicsItem* selectedItem : selectedItems)
 			selectedItem->setSelected(false);
 		clickedItem->setSelected(true);
 		m_currentPieces << clickedPiece;
@@ -91,7 +79,7 @@ bool Palapeli::MovePieceInteractor::startInteraction(const Palapeli::MouseEvent&
 	m_baseScenePosition = event.scenePos;
 	m_currentOffset = QPointF();
 	m_basePositions.clear();
-	foreach(Palapeli::Piece* piece, m_currentPieces)
+	for (Palapeli::Piece* piece : std::as_const(m_currentPieces))
 	{
 		m_basePositions << piece->pos();
 		connect(piece, &Piece::replacedBy, this, &MovePieceInteractor::pieceReplacedBy, Qt::DirectConnection);
@@ -135,9 +123,9 @@ void Palapeli::MovePieceInteractor::pieceReplacedBy(Palapeli::Piece* replacement
 void Palapeli::MovePieceInteractor::stopInteraction(const Palapeli::MouseEvent& event)
 {
 	Q_UNUSED(event)
-	foreach(Palapeli::Piece* piece, m_currentPieces)
+	for (Palapeli::Piece* piece : std::as_const(m_currentPieces))
 	{
-		disconnect(piece, 0, this, 0);
+		disconnect(piece, nullptr, this, nullptr);
 		piece->endMove();
 	}
 	m_currentPieces.clear();
@@ -196,7 +184,7 @@ bool Palapeli::TeleportPieceInteractor::startInteraction(const Palapeli::MouseEv
 	if (!view)
 		return false;
 	QGraphicsItem* item = findSelectableItemAt(event.scenePos, scene());
-	Palapeli::Piece* piece = 0;
+	Palapeli::Piece* piece = nullptr;
 	if (item) {
 		piece = Palapeli::Piece::fromSelectedItem(item);
 	}
@@ -242,6 +230,7 @@ Palapeli::ToggleCloseUpInteractor::ToggleCloseUpInteractor(QGraphicsView* view)
 
 bool Palapeli::ToggleCloseUpInteractor::startInteraction(const Palapeli::MouseEvent& event)
 {
+	Q_UNUSED(event);
 	qCDebug(PALAPELI_LOG) << "ENTERED ToggleCloseUpInteractor::startInteraction";
 	Palapeli::View* view = qobject_cast<Palapeli::View*>(this->view());
 	if (view)
@@ -401,7 +390,7 @@ void Palapeli::RubberBandInteractor::stopInteraction(const Palapeli::MouseEvent&
 	m_item->hide(); //NOTE: This is not necessary for the painting, but we use m_item->isVisible() to determine whether we are rubberbanding at the moment.
 	m_item->setRect(QRectF());	// Finalise the selection(s), if any.
 	const QList<QGraphicsItem*> selectedItems = scene()->selectedItems();
-	foreach (QGraphicsItem* selectedItem, selectedItems) {
+	for (QGraphicsItem* selectedItem : selectedItems) {
 		Palapeli::Piece* selectedPiece =
 			Palapeli::Piece::fromSelectedItem(selectedItem);
 		if (selectedPiece) {
