@@ -1,21 +1,9 @@
-/***************************************************************************
- *   Copyright 2009, 2010, 2011 Stefan Majewsky <majewsky@gmx.net>
- *   Copyright 2010 Johannes Löhnert <loehnert.kde@gmx.de>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009, 2010, 2011 Stefan Majewsky <majewsky@gmx.net>
+    SPDX-FileCopyrightText: 2010 Johannes Löhnert <loehnert.kde@gmx.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "piecevisuals.h"
 #include "mathtricks.h"
@@ -327,7 +315,7 @@ Palapeli::PieceVisuals Palapeli::mergeVisuals(const QList<Palapeli::PieceVisuals
 	//determine geometry of combined pixmap, and hold a vote on which representation to use
 	int imageCount = 0, pixmapCount = 0;
 	QRect combinedGeometry;
-	foreach (const Palapeli::PieceVisuals& sample, visuals)
+	for (const Palapeli::PieceVisuals& sample : visuals)
 	{
 		QRect sampleGeometry(sample.offset(), sample.size());
 		if (combinedGeometry.isNull())
@@ -345,7 +333,7 @@ Palapeli::PieceVisuals Palapeli::mergeVisuals(const QList<Palapeli::PieceVisuals
 		QPixmap combinedPixmap(combinedGeometry.size());
 		combinedPixmap.fill(Qt::transparent);
 		QPainter painter(&combinedPixmap);
-		foreach (const Palapeli::PieceVisuals& sample, visuals)
+		for (const Palapeli::PieceVisuals& sample : visuals)
 			painter.drawPixmap(sample.offset() - combinedOffset, sample.pixmap());
 		painter.end();
 		return Palapeli::PieceVisuals(combinedPixmap, combinedOffset);
@@ -355,7 +343,7 @@ Palapeli::PieceVisuals Palapeli::mergeVisuals(const QList<Palapeli::PieceVisuals
 		QImage combinedImage(combinedGeometry.size(), QImage::Format_ARGB32_Premultiplied);
 		combinedImage.fill(0x00000000); // == Qt::transparent
 		QPainter painter(&combinedImage);
-		foreach (const Palapeli::PieceVisuals& sample, visuals)
+		for (const Palapeli::PieceVisuals& sample : visuals)
 			painter.drawImage(sample.offset() - combinedOffset, sample.image());
 		painter.end();
 		return Palapeli::PieceVisuals(combinedImage, combinedOffset);
@@ -366,7 +354,7 @@ Palapeli::BevelMap Palapeli::mergeBevelMaps(const QList<Palapeli::PieceVisuals>&
 {
 	//determine geometry of combined pixmap
 	QRect combinedGeometry;
-	foreach (const Palapeli::PieceVisuals& sample, visuals)
+	for (const Palapeli::PieceVisuals& sample : visuals)
 	{
 		QRect sampleGeometry(sample.offset(), sample.size());
 		if (combinedGeometry.isNull())
