@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009-2011 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009-2011 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "collection.h"
 #include "collection_p.h"
@@ -24,9 +12,9 @@
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
-#include <QFutureWatcher>
 #include <QUuid>
 #include <QStandardPaths>
+#include <QProgressDialog>
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -43,14 +31,12 @@ Palapeli::Collection::Item::Item(Palapeli::Puzzle* puzzle)
 	//curly braces.
 	const QString id = puzzle->identifier();
 	setData(id, Palapeli::Collection::IdentifierRole);
-	setData(id.startsWith(QChar('{')), Palapeli::Collection::IsDeleteableRole);
+	setData(id.startsWith(QLatin1Char('{')), Palapeli::Collection::IsDeleteableRole);
 	setData(i18n("Loading puzzle..."), Qt::DisplayRole);
 	setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
 	//request metadata
-	Palapeli::FutureWatcher* watcher = new Palapeli::FutureWatcher;
-	connect(watcher, &QFutureWatcherBase::finished, this, &Item::populate);
-	connect(watcher, &QFutureWatcherBase::finished, watcher, &QObject::deleteLater);
-	watcher->setFuture(puzzle->get(Palapeli::PuzzleComponent::Metadata));
+	puzzle->get(Palapeli::PuzzleComponent::Metadata);
+	populate ();
 	//take ownership of puzzle
 	m_puzzle->QObject::setParent(this);
 }
@@ -70,9 +56,9 @@ void Palapeli::Collection::Item::populate()
 
 //END Palapeli::Collection::Item
 
-Palapeli::Collection* Palapeli::Collection::instance()
+Palapeli::Collection* Palapeli::Collection::instance(QWidget *parent)
 {
-	static Palapeli::Collection instance;
+	static Palapeli::Collection instance(parent);
 	return &instance;
 }
 
@@ -111,25 +97,31 @@ static QString readPseudoUrl(const QString& path_, bool local)
 		return path_;
 }
 
-Palapeli::Collection::Collection()
+Palapeli::Collection::Collection(QWidget *parent)
 	: m_config(new KConfig(QStringLiteral("palapeli-collectionrc"), KConfig::CascadeConfig))
 	, m_group(new KConfigGroup(m_config, "Palapeli Collection"))
 {
 	//read the puzzles
 	const QStringList puzzleIds = m_group->groupList();
-	foreach (const QString& puzzleId, puzzleIds)
+	int len = puzzleIds.length ();
+	int count = 0;
+	QProgressDialog dlg(i18n("Loading collection"), QString(), 0, len, parent);
+	dlg.setMinimumDuration(2000);
+	dlg.setWindowModality(Qt::WindowModal);
+	for (const QString& puzzleId : puzzleIds)
 	{
+		dlg.setValue(count++);
 		KConfigGroup* puzzleGroup = new KConfigGroup(m_group, puzzleId);
 		//find involved files
 		const QString basePath = puzzleGroup->readEntry("Location", QString());
 		const QString path = readPseudoUrl(basePath, false);
 		QString baseDesktopPath(basePath);
-		baseDesktopPath.replace(QRegExp("\\.puzzle$"), QLatin1String(".desktop"));
+		baseDesktopPath.replace(QRegExp(QStringLiteral("\\.puzzle$")), QLatin1String(".desktop"));
 		const QString desktopPath = readPseudoUrl(baseDesktopPath, false);
 		//construct puzzle with CollectionStorageComponent
 		if (!path.isEmpty() && (desktopPath.isEmpty() || QFileInfo(path).lastModified() >= QFileInfo(desktopPath).lastModified()))
 		{
-			Palapeli::Puzzle* puzzle = new Palapeli::Puzzle(new Palapeli::CollectionStorageComponent(puzzleGroup, &m_configMutex), path, puzzleId);
+			Palapeli::Puzzle* puzzle = new Palapeli::Puzzle(new Palapeli::CollectionStorageComponent(puzzleGroup), path, puzzleId);
 			appendRow(new Item(puzzle));
 			continue;
 		}
@@ -143,6 +135,9 @@ Palapeli::Collection::Collection()
 		//make sure puzzle gets converted to archive format
 		puzzle->get(Palapeli::PuzzleComponent::ArchiveStorage);
 	}
+	/* Moved out of CollectionStorageComponent, where we'd potentially call fdatasync on every
+	   puzzle.  */
+	m_config->sync();
 }
 
 Palapeli::Collection::~Collection()
@@ -163,7 +158,7 @@ Palapeli::Puzzle* Palapeli::Collection::puzzleFromIndex(const QModelIndex& index
 		if (item && item->puzzle()->identifier() == identifier)
 			return item->puzzle();
 	}
-	return 0;
+	return nullptr;
 }
 
 void Palapeli::Collection::importPuzzle(Palapeli::Puzzle* puzzle)
@@ -173,14 +168,12 @@ void Palapeli::Collection::importPuzzle(Palapeli::Puzzle* puzzle)
 	const QString palapeliUrl = QStringLiteral("palapeli:///collection/%1.puzzle").arg(id);
 	puzzle->setLocation(readPseudoUrl(palapeliUrl, true));
 	//store puzzle
-	puzzle->get(Palapeli::PuzzleComponent::ArchiveStorage).waitForFinished();
+	puzzle->get(Palapeli::PuzzleComponent::ArchiveStorage);
 	//create the config group for this puzzle (use pseudo-URL to avoid problems
 	//when the configuration directory is moved)
-	m_configMutex.lock();
 	KConfigGroup puzzleGroup(m_group, id);
 	puzzleGroup.writeEntry("Location", palapeliUrl);
 	m_config->sync();
-	m_configMutex.unlock();
 	//add to the model
 	appendRow(new Item(puzzle));
 }
@@ -207,7 +200,7 @@ void Palapeli::Collection::exportPuzzle(const QModelIndex& index, const QString&
 	//create a copy of the given puzzle, and relocate it to the new location
 	const QString identifier = Palapeli::Puzzle::fsIdentifier(path);
 	Palapeli::Puzzle* newPuzzle = new Palapeli::Puzzle(new Palapeli::CopyComponent(puzzle), path, identifier);
-	newPuzzle->get(Palapeli::PuzzleComponent::ArchiveStorage).waitForFinished();
+	newPuzzle->get(Palapeli::PuzzleComponent::ArchiveStorage);
 }
 
 bool Palapeli::Collection::deletePuzzle(const QModelIndex& index)
@@ -219,10 +212,8 @@ bool Palapeli::Collection::deletePuzzle(const QModelIndex& index)
 	if (!QFile(puzzle->location()).remove())
 		return false;
 	//remove puzzle from config
-	m_configMutex.lock();
 	KConfigGroup(m_group, puzzle->identifier()).deleteGroup();
 	m_config->sync();
-	m_configMutex.unlock();
 	//remove puzzle from model and delete it
 	const int count = rowCount();
 	for (int row = 0; row < count; ++row)
