@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2014 Ian Wadham <iandw.au@gmail.com>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Ian Wadham <iandw.au@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "pieceholder.h"
 #include "../engine/scene.h"
@@ -79,14 +67,14 @@ void Palapeli::PieceHolder::focusInEvent(QFocusEvent* e)
 	Q_UNUSED(e)
 	qCDebug(PALAPELI_LOG) << "PieceHolder::focusInEvent()" << windowTitle();
 	setSelected(true);
-	emit selected(this);	// De-select the previously selected holder.
+	Q_EMIT selected(this);	// De-select the previously selected holder.
 }
 
 void Palapeli::PieceHolder::setSelected(bool onOff)
 {
 	qCDebug(PALAPELI_LOG) << "PieceHolder::setSelected()" << windowTitle() << onOff;
 	setStyleSheet(QStringLiteral("QFrame { border: 3px solid %1; }").arg
-				(onOff ? "blue" : "lightGray"));
+				(onOff ? QLatin1String("blue") : QLatin1String("lightGray")));
 }
 
 void Palapeli::PieceHolder::closeEvent(QCloseEvent* event)
@@ -98,7 +86,7 @@ void Palapeli::PieceHolder::closeEvent(QCloseEvent* event)
 	else {
 		event->ignore();	// The window cannot be closed.
 	}
-	emit closing(this);		// GamePlay handles the details.
+	Q_EMIT closing(this);		// GamePlay handles the details.
 }
 
 
